function [ecc,epsilon,omega] = orbital_parameters_BER90(kyear)
t=-kyear.*1000; % convert kyr to yr and flip sign

% Load the tables from Berger & Loutre 1991
load('Berger.mat','Berger');
Table1 = Berger.Berger90.Table1;
Table4 = Berger.Berger90.Table4;
Table5 = Berger.Berger90.Table5;

% Constants from Table 9 in Berger 1991
psibar= 50.41726176./60./60. * pi/180;  % kbar
estar = 23.33340950;                    % eps *
zeta  = 1.60075265.* pi/180;            % alpha

twopi = 2*pi;
sectorad = pi/(180*60.*60);

% Order of table columns 'Term','Amp','Rate','Phase','Period'
M   = Table4(:,2);              % Amp
g   = Table4(:,3).*sectorad;    % Rate
b   = Table4(:,4).*pi./180;     % Phase
F   = Table5(:,2).*sectorad;    % Amp
fp  = Table5(:,3).*sectorad;    % Rate
d   = Table5(:,4).*pi./180;     % Phase
A   = Table1(:,2)./60./60;      % Amp
f   = Table1(:,3).*sectorad;    % Rate
phi = Table1(:,4).*pi./180;     % Phase

eps = estar + sum(A.*cos(f.*t+phi));

esinpi = sum(M.*sin(g.*t+b));
ecospi = sum(M.*cos(g.*t+b));
psi    = psibar.*t + zeta + sum(F.*sin(fp.*t +d));

e = sqrt(esinpi.^2+ecospi.^2);
Pi =atan(esinpi./ecospi)+pi*(ecospi<0);
eps = eps.* pi/180;
varpi = mod(Pi+psi+pi,twopi);

epsilon=eps;
ecc=e;
omega=varpi;

end
